@@ -3,7 +3,7 @@ BEGIN {
   $MooX::Cmd::Role::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $MooX::Cmd::Role::VERSION = '0.007';
+  $MooX::Cmd::Role::VERSION = '0.008';
 }
 # ABSTRACT: MooX cli app commands do this
 
@@ -137,8 +137,6 @@ sub _initialize_from_cmd
 {
 	my ( $class, %params ) = @_;
 
-	my @moox_cmd_chain = defined $params{__moox_cmd_chain} ? @{$params{__moox_cmd_chain}} : ();
-
 	my $opts_record = Data::Record->new({
 		split  => qr{\s+},
 		unless => $RE{quoted},
@@ -166,16 +164,16 @@ sub _initialize_from_cmd
 
 	defined $params{command_creation_chain_methods} or $params{command_creation_chain_methods} = $class->_build_command_creation_chain_methods(\%params);
 	my @creation_chain = _ARRAY($params{command_creation_chain_methods}) ? @{$params{command_creation_chain_methods}} : ($params{command_creation_chain_methods});
-	my $creation_method_name = first { $class->can($_) } @creation_chain;
-	croak "cant find a creation method on " . $class unless $creation_method_name;
+	my $creation_method_name = first { defined $_ and $class->can($_) } @creation_chain;
+	croak "Can't find a creation method on " . $class unless $creation_method_name;
 	my $creation_method = $class->can($creation_method_name); # XXX this is a perfect candidate for a new function in List::MoreUtils
 
 	@ARGV = @used_args;
 	$params{command_args} = [ @args ];
-	$params{command_chain} = \@moox_cmd_chain; # later modification hopefully will modify ...
 	$params{command_name} = $cmd_name;
+	defined $params{command_chain} or $params{command_chain} = [];
 	my $self = $creation_method->($class, %params);
-	$cmd and push @moox_cmd_chain, $self;
+	$cmd and push @{$self->command_chain}, $self;
 
 	my @execute_return;
 
@@ -183,26 +181,25 @@ sub _initialize_from_cmd
 	  or $params{command_execute_return_method_name} = $class->_build_command_execute_return_method_name(\%params);
 	if ($cmd) {
 		@ARGV = @args;
-		defined $params{command_creation_method_name} or $params{command_creation_method_name} = $class->_build_command_creation_method_name(\%params);
 		my ($creation_method,$creation_method_name,$cmd_plugin);
 		$cmd->can("_build_command_creation_method_name") and $creation_method_name = $cmd->_build_command_creation_method_name(\%params);
 		$creation_method_name and $creation_method = $cmd->can($creation_method_name);
 		if ($creation_method) {
-			$cmd_create_params{__moox_cmd_chain} = \@moox_cmd_chain;
+			@cmd_create_params{qw(command_chain)} = @params{qw(command_chain)};
 			$cmd_plugin = $creation_method->($cmd, %cmd_create_params);
 			@execute_return = @{ $call_indirect_method->($cmd_plugin, "command_execute_return_method_name") };
 		} else {
 			$creation_method_name = first { $cmd->can($_) } @creation_chain;
-			croak "cant find a creation method on " . $cmd unless $creation_method_name;
+			croak "Can't find a creation method on " . $cmd unless $creation_method_name;
 			$creation_method = $cmd->can($creation_method_name); # XXX this is a perfect candidate for a new function in List::MoreUtils
 			$cmd_plugin = $creation_method->($cmd);
 			defined $params{command_execute_from_new} or $params{command_execute_from_new} = $class->_build_command_execute_from_new(\%params);
 			$params{command_execute_from_new}
-			  and @execute_return = $call_required_method->($cmd_plugin, $cmd_create_params{command_execute_method_name}, \@ARGV,\@moox_cmd_chain);
+			  and @execute_return = $call_required_method->($cmd_plugin, $cmd_create_params{command_execute_method_name}, \@ARGV, $self->command_chain);
 		}
 	} else {
 		$self->command_execute_from_new
-		  and @execute_return = $call_indirect_method->($self, "command_execute_method_name", \@ARGV, \@moox_cmd_chain);
+		  and @execute_return = $call_indirect_method->($self, "command_execute_method_name", \@ARGV, $self->command_chain);
 	}
 
 	$self->{$params{command_execute_return_method_name}} = \@execute_return;
@@ -226,7 +223,7 @@ MooX::Cmd::Role - MooX cli app commands do this
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
